@@ -117,16 +117,6 @@ operation_parameter_map = {
             },
         ]
     },
-    '/snapTrade/encryptedJWT-GET': {
-        'parameters': [
-            {
-                'name': 'userId'
-            },
-            {
-                'name': 'userSecret'
-            },
-        ]
-    },
     '/snapTrade/listUsers-GET': {
         'parameters': [
         ]
@@ -189,6 +179,19 @@ operation_parameter_map = {
             },
         ]
     },
+    '/authorizations/{authorizationId}/disable-POST': {
+        'parameters': [
+            {
+                'name': 'authorizationId'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+        ]
+    },
     '/authorizations-GET': {
         'parameters': [
             {
@@ -199,6 +202,19 @@ operation_parameter_map = {
             },
         ]
     },
+    '/authorizations/{authorizationId}/refresh-POST': {
+        'parameters': [
+            {
+                'name': 'authorizationId'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+        ]
+    },
     '/authorizations/{authorizationId}-DELETE': {
         'parameters': [
             {
@@ -403,36 +419,36 @@ operation_parameter_map = {
     },
     '/trade/impact-POST': {
         'parameters': [
-            {
-                'name': 'userId'
-            },
-            {
-                'name': 'userSecret'
-            },
             {
                 'name': 'account_id'
             },
             {
                 'name': 'action'
             },
+            {
+                'name': 'universal_symbol_id'
+            },
             {
                 'name': 'order_type'
             },
+            {
+                'name': 'time_in_force'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
             {
                 'name': 'price'
             },
             {
                 'name': 'stop'
             },
-            {
-                'name': 'time_in_force'
-            },
             {
                 'name': 'units'
             },
-            {
-                'name': 'universal_symbol_id'
-            },
             {
                 'name': 'notional_value'
             },
@@ -459,12 +475,6 @@ operation_parameter_map = {
     },
     '/trade/place-POST': {
         'parameters': [
-            {
-                'name': 'userId'
-            },
-            {
-                'name': 'userSecret'
-            },
             {
                 'name': 'account_id'
             },
@@ -474,21 +484,30 @@ operation_parameter_map = {
             {
                 'name': 'order_type'
             },
+            {
+                'name': 'time_in_force'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'universal_symbol_id'
+            },
+            {
+                'name': 'symbol'
+            },
             {
                 'name': 'price'
             },
             {
                 'name': 'stop'
             },
-            {
-                'name': 'time_in_force'
-            },
             {
                 'name': 'units'
             },
-            {
-                'name': 'universal_symbol_id'
-            },
             {
                 'name': 'notional_value'
             },
