@@ -32,44 +32,12 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
-from snaptrade_client.model.exchange import Exchange as ExchangeSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
-from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
-from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
-from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
-from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
-from snaptrade_client.model.price import Price as PriceSchema
-from snaptrade_client.model.action import Action as ActionSchema
-from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
-from snaptrade_client.model.filled_units import FilledUnits as FilledUnitsSchema
-from snaptrade_client.model.cancelled_units import CancelledUnits as CancelledUnitsSchema
 from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
-from snaptrade_client.model.currency import Currency as CurrencySchema
-from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
-from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
 from snaptrade_client.model.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse as Model500UnexpectedExceptionResponseSchema
-from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
-from snaptrade_client.model.open_units import OpenUnits as OpenUnitsSchema
-from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus as AccountOrderRecordStatusSchema
 
-from snaptrade_client.type.account_order_record_status import AccountOrderRecordStatus
-from snaptrade_client.type.time_in_force import TimeInForce
-from snaptrade_client.type.security_type import SecurityType
-from snaptrade_client.type.filled_units import FilledUnits
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
-from snaptrade_client.type.stop_price import StopPrice
-from snaptrade_client.type.currency import Currency
-from snaptrade_client.type.price import Price
-from snaptrade_client.type.order_type import OrderType
-from snaptrade_client.type.action import Action
-from snaptrade_client.type.cancelled_units import CancelledUnits
-from snaptrade_client.type.options_symbol import OptionsSymbol
-from snaptrade_client.type.exchange import Exchange
-from snaptrade_client.type.us_exchange import USExchange
-from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
-from snaptrade_client.type.open_units import OpenUnits
 from snaptrade_client.type.model500_unexpected_exception_response import Model500UnexpectedExceptionResponse
-from snaptrade_client.type.universal_symbol import UniversalSymbol
 from snaptrade_client.type.account_order_record import AccountOrderRecord
 
 from . import path
@@ -147,7 +115,7 @@ class SchemaForRequestBodyApplicationJson(
     class MetaOapg:
         
         class properties:
-            brokerage_order_id = schemas.UUIDSchema
+            brokerage_order_id = schemas.StrSchema
             __annotations__ = {
                 "brokerage_order_id": brokerage_order_id,
             }
@@ -176,7 +144,7 @@ class SchemaForRequestBodyApplicationJson(
     def __new__(
         cls,
         *args: typing.Union[dict, frozendict.frozendict, ],
-        brokerage_order_id: typing.Union[MetaOapg.properties.brokerage_order_id, str, uuid.UUID, schemas.Unset] = schemas.unset,
+        brokerage_order_id: typing.Union[MetaOapg.properties.brokerage_order_id, str, schemas.Unset] = schemas.unset,
         _configuration: typing.Optional[schemas.Configuration] = None,
         **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
     ) -> 'SchemaForRequestBodyApplicationJson':
@@ -309,17 +277,18 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
         AsyncGeneratorResponse,
     ]:
         """
-        Cancel open order in account
+        Cancel order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -372,6 +341,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/accounts/{accountId}/orders/cancel',
             body=body,
             auth_settings=_auth,
             headers=_headers,
@@ -392,6 +362,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -454,7 +425,7 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
@@ -463,7 +434,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Cancel open order in account
+        Cancel order
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -516,6 +487,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/accounts/{accountId}/orders/cancel',
             body=body,
             auth_settings=_auth,
             headers=_headers,
@@ -574,6 +546,7 @@ class CancelUserAccountOrder(BaseApi):
         brokerage_order_id: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -592,6 +565,7 @@ class CancelUserAccountOrder(BaseApi):
             body=args.body,
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def cancel_user_account_order(
@@ -607,6 +581,7 @@ class CancelUserAccountOrder(BaseApi):
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Attempts to cancel an open order with the brokerage. If the order is no longer cancellable, the request will be rejected.  """
         args = self._cancel_user_account_order_mapped_args(
             body=body,
             query_params=query_params,
@@ -634,6 +609,7 @@ class ApiForpost(BaseApi):
         brokerage_order_id: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -652,6 +628,7 @@ class ApiForpost(BaseApi):
             body=args.body,
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def post(
@@ -667,6 +644,7 @@ class ApiForpost(BaseApi):
         ApiResponseFor200,
         api_client.ApiResponseWithoutDeserialization,
     ]:
+        """ Attempts to cancel an open order with the brokerage. If the order is no longer cancellable, the request will be rejected.  """
         args = self._cancel_user_account_order_mapped_args(
             body=body,
             query_params=query_params,
